@@ -23,10 +23,10 @@ class Interconnection:
     """Calculate interconnection costs per grid cell in $ / yr using:
 
     Interconnection Cost ($ / yr) = Distance to nearest suitable transmission line (km) *
-                                        Electric grid interconnection captial cost ($ / km) *
+                                        Electric grid interconnection captial cost (thous$ / km) *
                                         Annuity factor
                                         + (if gas-fired technology) Distance to nearest suitable gas pipeline (km) *
-                                        Gas interconnection captial cost ($ / km) *
+                                        Gas interconnection captial cost (thous$ / km) *
                                         Annuity factor
 
             where, Annuity factor is (d(1 + d)**n) / ((1 + d)**n - 1)
@@ -140,10 +140,10 @@ class Interconnection:
         self.pipeline_costs = self.transmission_to_cost_raster(setting='pipelines')
 
     @staticmethod
-    def calc_annuity_factor(discount_rate, lifetime):
+    def calc_annuity_factor(discount_rate, lifetime_yrs):
         """Calculate annuity factor."""
 
-        fx = pow(1.0 + discount_rate, lifetime)
+        fx = pow(1.0 + discount_rate, lifetime_yrs)
 
         return discount_rate * fx / (fx - 1.0)
 
@@ -179,14 +179,12 @@ class Interconnection:
             self.transmission_costs_dict = pkg.costs_per_kv_substation()
 
         elif self.transmission_costs_file is not None:
-
             logging.info(f"Using substation costs from file: {self.transmission_costs_file}")
 
             with open(self.transmission_costs_file, 'r') as yml:
                 self.transmission_costs_dict = yaml.load(yml, Loader=yaml.FullLoader)
 
         if self.substation_file is None:
-
             sub_file = pkg.get_substation_file()
 
             logging.info(f"Using default substation file: {sub_file}")
@@ -216,11 +214,16 @@ class Interconnection:
                 # assign a field to rasterize by containing the cost of transmission per km
                 gdf['_rval_'] = 0
 
-                for i in self.transmission_costs_dict.keys():
-                    gdf['_rval_'] = np.where((gdf['min_volt'] >= self.transmission_costs_dict[i]['min_voltage']) &
-                                             (gdf['min_volt'] <= self.transmission_costs_dict[i]['max_voltage']),
-                                             self.transmission_costs_dict[i]['thous_dollar_per_km'],
-                                             gdf['_rval_'])
+                # check for the presence of a minimum voltage field
+                if 'min_volt' in gdf.columns:
+
+                    for i in self.transmission_costs_dict.keys():
+                        gdf['_rval_'] = np.where((gdf['min_volt'] >= self.transmission_costs_dict[i]['min_voltage']) &
+                                                 (gdf['min_volt'] <= self.transmission_costs_dict[i]['max_voltage']),
+                                                 self.transmission_costs_dict[i]['thous_dollar_per_km'],
+                                                 gdf['_rval_'])
+                else:
+                    raise KeyError(f"Substations file must have a field named `min_volt` containing the minimum voltage.")
 
                 return gdf
 
@@ -320,8 +323,12 @@ class Interconnection:
                 out_alloc = os.path.join(tempdir, f'cerf_transmission_allocation_{setting}.tif')
                 out_costs = os.path.join(tempdir, f'cerf_transmission_costs_{setting}.tif')
 
+            # update source file nodata value to nan to ensure a fill of 0 can occur for the background
+            metadata.update({"nodata": -np.nan})
+
             # rasterize transmission vector data and write to memory
             with rasterio.open(out_rast, 'w', **metadata) as dataset:
+
                 # burn features into raster
                 burned = features.rasterize(shapes=shapes, fill=0, out=arr, transform=dataset.transform)
 
@@ -365,10 +372,10 @@ class Interconnection:
             # get technology specific information
             require_pipelines = self.technology_dict[i].get('require_pipelines', False)
             discount_rate = self.technology_dict[i].get('discount_rate')
-            lifetime = self.technology_dict[i].get('lifetime')
+            lifetime_yrs = self.technology_dict[i].get('lifetime_yrs')
 
             # calculate annuity factor for technology
-            annuity_factor = self.calc_annuity_factor(discount_rate=discount_rate, lifetime=lifetime)
+            annuity_factor = self.calc_annuity_factor(discount_rate=discount_rate, lifetime_yrs=lifetime_yrs)
 
             # get transmission cost array and convert from thous$/km to $/km
             substation_cost_array = self.substation_costs * annuity_factor * 1000
@@ -393,7 +400,7 @@ class Interconnection:
 def preprocess_hifld_substations(substation_file, output_file=None):
     """Select substations from HIFLD data that are within the CONUS and either in service or under construction and
     having a minimum voltage rating >= 0.  A field used to rasterize ('_rval_') is also added containing the cost of
-    connection in $/km for each substation.
+    connection in thous$/km for each substation.
 
     This data is assumed to have the following fields:  ['TYPE', 'STATE', 'STATUS'].
 
